@@ -19,6 +19,8 @@ from oslo_serialization import jsonutils
 
 from keystoneauth1 import exceptions
 
+from mistralclient import utils
+
 urlparse = urllib.parse
 
 
@@ -73,8 +75,15 @@ def extract_json(response, response_key):
 class ResourceManager(object):
     resource_class = None
 
-    def __init__(self, http_client):
+    def __init__(self, http_client, enforce_raw_definitions=False):
         self.http_client = http_client
+        self.enforce_raw_definitions = enforce_raw_definitions
+
+    def get_contents_if_file(self, contents_or_file_name):
+        if self.enforce_raw_definitions:
+            return contents_or_file_name
+        else:
+            return utils.get_contents_if_file(contents_or_file_name)
 
     def find(self, **kwargs):
         return [i for i in self.list() if _check_items(i, kwargs.items())]
